aboutsummaryrefslogtreecommitdiffstats
path: root/plugins/reception-plugins/src/test/java
diff options
context:
space:
mode:
authorramverma <ram.krishna.verma@ericsson.com>2018-08-23 13:50:31 +0100
committerramverma <ram.krishna.verma@ericsson.com>2018-08-24 10:04:31 +0100
commitef2ff6bae65870a4fccc25373c0cfae881e14a81 (patch)
tree2329de6759a3f74237b8a64dcbe63d7114f532ef /plugins/reception-plugins/src/test/java
parent55e6bdc93d05f1c9673a4ecbe133207722216eb0 (diff)
Fix sonar and checkstyle issues in distribution
* Fixing all check style issues. * Fixing all sonar issues. * Adding maven check style plugin to fail at warning level. Change-Id: I791b8feef39a3a0c3e1e250efea7b6e78208bf07 Issue-ID: POLICY-1035 Signed-off-by: ramverma <ram.krishna.verma@ericsson.com>
Diffstat (limited to 'plugins/reception-plugins/src/test/java')
-rw-r--r--plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/PssdConfigurationTest.java (renamed from plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/PSSDConfigurationTest.java)40
-rw-r--r--plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdControllerExceptionTest.java (renamed from plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDControllerExceptionTest.java)6
-rw-r--r--plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdDownloadExceptionTest.java (renamed from plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDDownloadExceptionTest.java)6
-rw-r--r--plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdParametersExceptionTest.java (renamed from plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDParametersExceptionTest.java)6
4 files changed, 28 insertions, 30 deletions
diff --git a/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDControllerExceptionTest.java b/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdControllerExceptionTest.java
index b467cbad..5f8e507a 100644
--- a/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDControllerExceptionTest.java
+++ b/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdControllerExceptionTest.java
@@ -26,11 +26,11 @@ import java.io.IOException;
import org.junit.Test;
-public class PSSDControllerExceptionTest {
+public class PssdControllerExceptionTest {
@Test
public void test() {
- assertNotNull(new PSSDControllerException("Message"));
- assertNotNull(new PSSDControllerException("Message", new IOException()));
+ assertNotNull(new PssdControllerException("Message"));
+ assertNotNull(new PssdControllerException("Message", new IOException()));
}
}
diff --git a/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDDownloadExceptionTest.java b/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdDownloadExceptionTest.java
index 0ca4330d..9f76b375 100644
--- a/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDDownloadExceptionTest.java
+++ b/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdDownloadExceptionTest.java
@@ -26,11 +26,11 @@ import java.io.IOException;
import org.junit.Test;
-public class PSSDDownloadExceptionTest {
+public class PssdDownloadExceptionTest {
@Test
public void test() {
- assertNotNull(new PSSDDownloadException("Message"));
- assertNotNull(new PSSDDownloadException("Message", new IOException()));
+ assertNotNull(new PssdDownloadException("Message"));
+ assertNotNull(new PssdDownloadException("Message", new IOException()));
}
}
diff --git a/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDParametersExceptionTest.java b/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdParametersExceptionTest.java
index 040895e6..7a1f5512 100644
--- a/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PSSDParametersExceptionTest.java
+++ b/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/exceptions/PssdParametersExceptionTest.java
@@ -26,11 +26,11 @@ import java.io.IOException;
import org.junit.Test;
-public class PSSDParametersExceptionTest {
+public class PssdParametersExceptionTest {
@Test
public void test() {
- assertNotNull(new PSSDParametersException("Message"));
- assertNotNull(new PSSDParametersException("Message", new IOException()));
+ assertNotNull(new PssdParametersException("Message"));
+ assertNotNull(new PssdParametersException("Message", new IOException()));
}
}
diff --git a/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/PSSDConfigurationTest.java b/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/PssdConfigurationTest.java
index 435b7577..5c24a792 100644
--- a/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/PSSDConfigurationTest.java
+++ b/plugins/reception-plugins/src/test/java/org/onap/policy/distribution/reception/handling/sdc/PssdConfigurationTest.java
@@ -5,15 +5,15 @@
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
- *
+ *
* http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- *
+ *
* SPDX-License-Identifier: Apache-2.0
* ============LICENSE_END=========================================================
*/
@@ -28,50 +28,48 @@ import static org.junit.Assert.fail;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
-import java.io.File;
import java.io.FileReader;
import java.io.IOException;
+
import org.junit.Test;
import org.onap.policy.common.parameters.GroupValidationResult;
-import org.onap.policy.distribution.reception.parameters.PSSDConfigurationParametersGroup;
+import org.onap.policy.distribution.reception.parameters.PssdConfigurationParametersGroup;
/*-
* Tests for PSSDConfiguration class
*
*/
-public class PSSDConfigurationTest {
-
+public class PssdConfigurationTest {
+
@Test
- public void testPSSDConfigurationParametersGroup() throws IOException {
- PSSDConfigurationParametersGroup configParameters = null;
+ public void testPssdConfigurationParametersGroup() throws IOException {
+ PssdConfigurationParametersGroup configParameters = null;
try {
final Gson gson = new GsonBuilder().create();
- configParameters =
- gson.fromJson(new FileReader("src/test/resources/handling-sdc.json"),
- PSSDConfigurationParametersGroup.class);
+ configParameters = gson.fromJson(new FileReader("src/test/resources/handling-sdc.json"),
+ PssdConfigurationParametersGroup.class);
} catch (final Exception e) {
fail("test should not thrown an exception here: " + e.getMessage());
}
final GroupValidationResult validationResult = configParameters.validate();
assertTrue(validationResult.isValid());
- PSSDConfiguration config = new PSSDConfiguration(configParameters);
+ final PssdConfiguration config = new PssdConfiguration(configParameters);
assertEquals(20, config.getPollingInterval());
- assertEquals(30,config.getPollingTimeout());
+ assertEquals(30, config.getPollingTimeout());
}
@Test
- public void testInvalidPSSDConfigurationParametersGroup() throws IOException {
- PSSDConfigurationParametersGroup configParameters = null;
+ public void testInvalidPssdConfigurationParametersGroup() throws IOException {
+ PssdConfigurationParametersGroup configParameters = null;
try {
final Gson gson = new GsonBuilder().create();
- configParameters =
- gson.fromJson(new FileReader("src/test/resources/handling-sdcInvalid.json"),
- PSSDConfigurationParametersGroup.class);
+ configParameters = gson.fromJson(new FileReader("src/test/resources/handling-sdcInvalid.json"),
+ PssdConfigurationParametersGroup.class);
} catch (final Exception e) {
fail("test should not thrown an exception here: " + e.getMessage());
}
final GroupValidationResult validationResult = configParameters.validate();
assertFalse(validationResult.isValid());
-
+
}
}
@@ -28,50 +28,48 @@ import static org.junit.Assert.fail;
/*-
- * Tests for PSSDConfiguration class
+ * Tests for PssdConfiguration class
*
*/